fragment MemberFragment on Member {
  id
  isBusiness
  accountType
  businessName
  businessRegistrationNumber
  registrationCompleted
  fullyChargedPreregistered
  investmentTotal
  billSavingsAcrossAllProjects
  expectedGenerationAnnualTotal
  ownershipPercentageTotal
  capacityOwnedTotal
  hasReservedInActiveCoop
  dateOfReservationInActiveCoop
  dateOfLastSharePurchase
  hasBoughtSharesInActiveCoop
  hasBoughtSharesInGraigFatha
  hasBoughtSharesInKirkHill
  hasBoughtSharesInMultipleCoops
  isSuppliedByOctopusEnergy
  memberDocument {
    id
    file
    documentUrl
  }
  address {
    id
    line1
    line2
    town
    postcode
    manuallyEntered
  }
  badges {
    id
    name
    code
    description
    imageUrl
  }
  beneficiaries {
    id
    nominatedPerson
    email
    phone
    line1
    line2
    town
    postcode
  }
  invoices {
    id
    category
    quote {
      id
      arrangementFee
      billSavingsAnnualEstimate
      capacity
      costTotal
      costTotalLocale
      currency {
        code
        precision
        symbol
      }
      ownershipMultiplier
      paymentTotal
      paymentTotalLocale
      electricityConsumptionAnnual
    }
  }
  memberships {
    id
    capacity
    reservedCapacity
    createdAt
    expectedGenerationAnnualTotal
    ownershipPercentage
    investmentTotal
    billSavingsForProjectLifespan
    billSavingsFirstYearEstimateTotal
    firstOwnershipPurchaseDate
    coop {
      ...CoopFragment
    }
    lightShowImage
  }
  currentMemberSupplier {
    id
    accountIdentifier
    supplier {
      id
      name
      logoUrl
    }
  }
  waitingListPlaces {
    ...WaitingListPlaceFragment
  }
}