fragment ConsumptionFragment on MemberConsumption {
  id
  electricityAnnualKwh
  fromCalculator
  peopleCount
  bedroomsCount
  hasElectricVehicle
  hasElectricHeating
  hasHeatPump
  hasSolarPanels
  solarPanelsCapacity
  acknowledgesToProvideBillEvidence
}